<?php /*
Plugin Name:    Daze Pop-out pages
Description:    Custom post type for displaying some small content in a lightbox
Version:		1.0
Author:         NordWood Themes
Author URI:		http://nordwoodthemes.com/
Text Domain:	daze-popout-pages
*/

/* CREATE INFO LIGHTBOX
   ========================================================================== */
	if ( ! function_exists( 'daze_popout_init' ) ):
	function daze_popout_init() {
		$labels = array(
			'name'               => esc_html_x( 'Pop-out page', 'post type general name', 'daze-popout-pages' ),
			'singular_name'      => esc_html_x( 'Pop-out page', 'post type singular name', 'daze-popout-pages' ),
			'menu_name'          => esc_html_x( 'Pop-out pages', 'admin menu', 'daze-popout-pages' ),
			'name_admin_bar'     => esc_html_x( 'Pop-out page', 'add new on admin bar', 'daze-popout-pages' ),
			'add_new'            => esc_html_x( 'Add New', 'add new', 'daze-popout-pages' ),
			'add_new_item'       => esc_html__( 'New Pop-out page', 'daze-popout-pages' ),
			'new_item'           => esc_html__( 'New Pop-out page', 'daze-popout-pages' ),
			'edit_item'          => esc_html__( 'Edit Pop-out page', 'daze-popout-pages' ),
			'view_item'          => esc_html__( 'View Pop-out page', 'daze-popout-pages' ),
			'all_items'          => esc_html__( 'Pop-out pages', 'daze-popout-pages' ),
			'search_items'       => esc_html__( 'Search Pop-out pages', 'daze-popout-pages' ),
			'parent_item_colon'  => esc_html__( 'Parent Pop-out pages:', 'daze-popout-pages' ),
			'not_found'          => esc_html__( 'No Pop-out pages found.', 'daze-popout-pages' ),
			'not_found_in_trash' => esc_html__( 'No Pop-out pages found in Trash.', 'daze-popout-pages' )
		);

		$args = array(
			'labels'              => $labels,
			'has_archive'		  => false,
			'public'              => true,
			'exclude_from_search' => true,
			'show_in_nav_menus'   => true,
			'show_in_menu'        => true,
			'query_var'           => true,
			'rewrite'             => array( 'slug' => 'popout' ),
			'capability_type'     => 'post',
			'hierarchical'        => false,
			'menu_position'       => 5,
			'menu_icon'			  => 'dashicons-info',
			'supports'            => array( 'title', 'editor', 'thumbnail' ),
			'taxonomies'		  => array( 'post_tag' )
		);

		register_post_type( 'popout', $args );
	}
	endif;
	add_action( 'init', 'daze_popout_init' );
	
/* REWRITE FLUSH
   ========================================================================== */
	if ( ! function_exists( 'daze_popout_rewrite_flush' ) ):
	function daze_popout_rewrite_flush() {
		daze_popout_init();
		flush_rewrite_rules();
	}
	endif;
	register_activation_hook( __FILE__, 'daze_popout_rewrite_flush' );	
	
/* WP MESSAGES
   ========================================================================== */
	if ( ! function_exists( 'daze_popout_update_messages' ) ):
		function daze_popout_update_messages( $messages ) {
			global $post;

			$post_ID = $post->ID;
			$post_type = get_post_type( $post_ID );

			$obj = get_post_type_object( $post_type );
			$singular = $obj->labels->singular_name;

			$messages[$post_type] = array(
					0 => '', // Unused. Messages start at index 1.
					1 => sprintf( __( '%s updated. <a href="%s" target="_blank">View %s</a>', 'daze-popout-pages' ), esc_attr( $singular ), esc_url( get_permalink( $post_ID ) ), strtolower( $singular ) ),
					2 => esc_html__( 'Custom field updated.', 'daze-popout-pages' ),
					3 => esc_html__( 'Custom field deleted.', 'daze-popout-pages' ),
					4 => sprintf( esc_html__( '%s updated.', 'daze-popout-pages' ), esc_attr( $singular ) ),
					5 => isset( $_GET['revision']) ? sprintf( esc_html__('%2$s restored to revision from %1$s', 'daze-popout-pages' ), wp_post_revision_title( (int) $_GET['revision'], false ), esc_attr( $singular ) ) : false,
					6 => sprintf( esc_html__( '%s published. <a href="%s">View %s</a>'), $singular, esc_url( get_permalink( $post_ID ) ), strtolower( $singular ) ),
					7 => sprintf( esc_html__( '%s saved.', 'daze-popout-pages' ), esc_attr( $singular ) ),
					8 => sprintf( __( '%s submitted. <a href="%s" target="_blank">Preview %s</a>', 'daze-popout-pages'), $singular, esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ), strtolower( $singular ) ),
					9 => sprintf( __( '%s scheduled for: <strong>%s</strong>. <a href="%s" target="_blank">Preview %s</a>', 'daze-popout-pages' ), $singular, date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink( $post_ID ) ), strtolower( $singular ) ),
					10 => sprintf( __( '%s draft updated. <a href="%s" target="_blank">Preview %s</a>'), $singular, esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ), strtolower( $singular ) )
			);

			return $messages;
		}
	endif;
	add_filter( 'post_updated_messages', 'daze_popout_update_messages' );	
	
/* CUSTOM FIELDS
   ========================================================================== */
	if ( ! function_exists( 'daze_popout_get_meta' ) ):
	function daze_popout_get_meta( $value ) {
		global $post;

		$field = get_post_meta( $post->ID, $value, true );
		if ( ! empty( $field ) ) {
			return is_array( $field ) ? stripslashes_deep( $field ) : stripslashes( wp_kses_decode_entities( $field ) );
		} else {
			return false;
		}
	}
	endif;

	if ( ! function_exists( 'daze_popout_add_meta_box' ) ):
	function daze_popout_add_meta_box() {
		add_meta_box(
			'daze_popout_pages_meta_box-daze-popout-pages-meta-boxes',
			esc_html__( 'Options', 'daze-popout-pages' ),
			'daze_popout_html',
			'popout',
			'advanced',
			'default'
		);
	}
	endif;
	add_action( 'add_meta_boxes', 'daze_popout_add_meta_box' );

	if ( ! function_exists( 'daze_popout_html' ) ):
	function daze_popout_html( $post) {
		wp_nonce_field( '_daze_popout_nonce', 'daze_popout_nonce' ); ?>
		
		<div class="daze-metabox-section">			
			<fieldset>
				<input type="checkbox"
					name="daze_popout_hide_title"
					id="daze_popout_hide_title"
					value="hide-title"
					<?php echo ( daze_popout_get_meta( 'daze_popout_hide_title' ) === 'hide-title' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_hide_title"><?php esc_html_e( 'hide title', 'daze-popout-pages' ); ?></label>
			</fieldset>
		</div>
		
		<div class="daze-metabox-section">
			<fieldset>	
				<h5><strong><?php esc_html_e( 'Featured image position', 'daze-popout-pages' ); ?></strong></h5>

				<input type="radio"
					name="daze_popout_img_position"
					id="daze_popout_img_position_0"
					value="featured-image-top"
					checked <?php echo ( daze_popout_get_meta( 'daze_popout_img_position' ) === 'featured-image-top' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_img_position_0"><?php esc_html_e( 'top', 'daze-popout-pages' ); ?></label>

				<input type="radio"
					name="daze_popout_img_position"
					id="daze_popout_img_position_1"
					value="featured-image-right"
					<?php echo ( daze_popout_get_meta( 'daze_popout_img_position' ) === 'featured-image-right' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_img_position_1"><?php esc_html_e( 'right', 'daze-popout-pages' ); ?></label>
			</fieldset>
			
			<fieldset>
				<h5><strong><?php esc_html_e( 'Featured image type', 'daze-popout-pages' ); ?></strong></h5>
				
				<input type="radio"
					name="daze_popout_img_shape"
					id="daze_popout_img_shape_0"
					value="featured-image-natural"
					checked <?php echo ( daze_popout_get_meta( 'daze_popout_img_shape' ) === 'featured-image-natural' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_img_shape_0"><?php esc_html_e( 'natural', 'daze-popout-pages' ); ?></label>

				<input type="radio"
					name="daze_popout_img_shape"
					id="daze_popout_img_shape_1"
					value="featured-image-rounded"
					<?php echo ( daze_popout_get_meta( 'daze_popout_img_shape' ) === 'featured-image-rounded' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_img_shape_1"><?php esc_html_e( 'rounded', 'daze-popout-pages' ); ?></label>				
			</fieldset>
			
			<fieldset>						
				<p><label for="daze_popout_img_link"><?php esc_html_e( 'Featured image links to (insert URL):', 'daze-popout-pages' ); ?></label>
				<input type="url" class="widefat"
					name="daze_popout_img_link"
					id="daze_popout_img_link"
					value="<?php echo esc_url_raw( daze_popout_get_meta( 'daze_popout_img_link' ) ); ?>"
				></p>
				
				<input type="checkbox"
					name="daze_popout_img_link_new_tab"
					id="daze_popout_img_link_new_tab"
					value="new-tab"
					<?php echo ( daze_popout_get_meta( 'daze_popout_img_link_new_tab' ) === 'new-tab' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_img_link_new_tab"><?php esc_html_e( 'Open link in new tab', 'daze-popout-pages' ); ?></label>
			</fieldset>
		</div>
		
		<div class="daze-metabox-section">
			<h5>&nbsp;</h5>
			<fieldset>			
				<input type="checkbox"
					name="daze_popout_on_load"
					id="daze_popout_on_load"
					value="on-load"
					<?php echo ( daze_popout_get_meta( 'daze_popout_on_load' ) === 'on-load' ) ? 'checked' : ''; ?>
				>
				<label for="daze_popout_on_load"><h5><?php esc_html_e( 'Show on site load', 'daze-popout-pages' ); ?></h5></label>
			
				<p><label for="daze_popout_on_load_timeout"><?php esc_html_e( 'Show pop-out X seconds after the site loads', 'daze-popout-pages' ); ?></label>
				<input type="number"
					name="daze_popout_on_load_timeout"
					id="daze_popout_on_load_timeout"
					placeholder="0"
					value="<?php echo absint( daze_popout_get_meta( 'daze_popout_on_load_timeout' ) ); ?>"
				></p>
			
				<p><label for="daze_popout_on_load_expire"><?php esc_html_e( 'Show pop-out again in X hours', 'daze-popout-pages' ); ?></label>
				<input type="number"
					name="daze_popout_on_load_expire"
					id="daze_popout_on_load_expire"
					placeholder="24"
					value="<?php echo absint( daze_popout_get_meta( 'daze_popout_on_load_expire' ) ); ?>"
				></p>
			</fieldset>
		</div>
	<?php
	}
	endif;

	if ( ! function_exists( 'daze_popout_save_meta' ) ):
	function daze_popout_save_meta( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
		if ( ! isset( $_POST['daze_popout_nonce'] ) || ! wp_verify_nonce( $_POST['daze_popout_nonce'], '_daze_popout_nonce' ) ) return;
		if ( ! current_user_can( 'edit_post', $post_id ) ) return;

		if ( isset( $_POST['daze_popout_hide_title'] ) )
			update_post_meta( $post_id, 'daze_popout_hide_title', sanitize_text_field( $_POST['daze_popout_hide_title'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_hide_title', null );

		if ( isset( $_POST['daze_popout_img_position'] ) )
			update_post_meta( $post_id, 'daze_popout_img_position', sanitize_text_field( $_POST['daze_popout_img_position'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_img_position', null );

		if ( isset( $_POST['daze_popout_img_shape'] ) )
			update_post_meta( $post_id, 'daze_popout_img_shape', sanitize_text_field( $_POST['daze_popout_img_shape'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_img_shape', null );

		if ( isset( $_POST['daze_popout_img_link'] ) )
			update_post_meta( $post_id, 'daze_popout_img_link', sanitize_text_field( $_POST['daze_popout_img_link'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_img_link', null );

		if ( isset( $_POST['daze_popout_img_link_new_tab'] ) )
			update_post_meta( $post_id, 'daze_popout_img_link_new_tab', sanitize_text_field( $_POST['daze_popout_img_link_new_tab'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_img_link_new_tab', null );

		if ( isset( $_POST['daze_popout_on_load'] ) )
			update_post_meta( $post_id, 'daze_popout_on_load', sanitize_text_field( $_POST['daze_popout_on_load'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_on_load', null );

		if ( isset( $_POST['daze_popout_on_load_timeout'] ) )
			update_post_meta( $post_id, 'daze_popout_on_load_timeout', absint( $_POST['daze_popout_on_load_timeout'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_on_load_timeout', null );

		if ( isset( $_POST['daze_popout_on_load_expire'] ) )
			update_post_meta( $post_id, 'daze_popout_on_load_expire', absint( $_POST['daze_popout_on_load_expire'] ) );
		else
			update_post_meta( $post_id, 'daze_popout_on_load_expire', null );
	}
	endif;
	add_action( 'save_post', 'daze_popout_save_meta' );

/* USAGE
   ========================================================================== */
	/*
	daze_popout_get_meta( 'daze_popout_on_load' );
	daze_popout_get_meta( 'daze_popout_on_load_timeout' );
	daze_popout_get_meta( 'daze_popout_on_load_expire' );
	daze_popout_get_meta( 'daze_popout_img_position' );
	daze_popout_get_meta( 'daze_popout_img_shape' );
	daze_popout_get_meta( 'daze_popout_img_link' );
	daze_popout_get_meta( 'daze_popout_img_link_new_tab' );
	*/
	
/* CUSTOM TEMPLATES
   ========================================================================== */
	if ( ! function_exists( 'daze_popout_template' ) ):
	function daze_popout_template( $template_path ) {		
		if ( get_post_type() == 'popout' ) {
			if ( is_single() )
				$template_path = plugin_dir_path( __FILE__ ) . 'single-popout.php';
		}
		return $template_path;
	}
	endif;
	add_filter( 'template_include', 'daze_popout_template', 1 );	

	
/* SCRIPTS & STYLES
   ========================================================================== */   
	if ( !function_exists( 'daze_popout_admin' ) ):
		function daze_popout_admin($hook) {
			if( ( 'post.php' != $hook && 'post-new.php' != $hook ) || wp_script_is( 'daze_metaboxes', 'enqueued' ) ) return;	
			
			wp_enqueue_style( 'daze_metaboxes_popout', plugins_url( '/css/metaboxes.css' , __FILE__ ) );
		}
	endif;
	add_action('admin_enqueue_scripts', 'daze_popout_admin');	
	
	
	if ( !function_exists( 'daze_popout_register' ) ) :
		function daze_popout_register() {
			wp_register_style( 'daze_popout', plugins_url( '/css/popout.css' , __FILE__ ) );
			wp_register_script( 'daze_assets_images_loaded', plugins_url( '/assets/images-loaded/imagesloaded.pkgd.js' , __FILE__ ), array('jquery'), '', true );
			wp_register_script( 'daze_popout', plugins_url( '/js/popout.js' , __FILE__ ), array('jquery', 'daze_assets_images_loaded'), false, false );
			wp_register_script( 'daze_popout_onload', plugins_url( '/js/popout-onload.js' , __FILE__ ), array('jquery', 'daze_popout', 'daze_assets_images_loaded'), false, false );
			
			wp_enqueue_style( 'daze_popout' );
			
			if( is_page('masonry-3-cols') ) :
				$onload_args_args = array(
					'post_type' => 'popout',
					'posts_per_page' => 1,
					'meta_query' => array(
						array(
						   'key' => 'daze_popout_on_load',
						   'value' => 'on-load',
						   'compare' => 'LIKE'
						)
					 )					
				);

				$onload_args_query = new WP_Query( $onload_args_args );
				
				if ( $onload_args_query->have_posts() ) :
					while( $onload_args_query->have_posts() ) :
						$onload_args_query->the_post();
						$permalink = get_permalink();
						$timeout = daze_popout_get_meta( 'daze_popout_on_load_timeout' ) ? absint( daze_popout_get_meta( 'daze_popout_on_load_timeout' ) ) : 1;
						$expires = daze_popout_get_meta( 'daze_popout_on_load_expire' ) ? absint( daze_popout_get_meta( 'daze_popout_on_load_expire' ) ) : 24;
					endwhile;
					
					$on_load = array(
						'permalink'	=> $permalink,
						'timeout' => $timeout,
						'expires' => $expires
					);
					
					wp_localize_script( 'daze_popout_onload', 'on_load', $on_load );
					wp_enqueue_script( 'daze_popout_onload' );
				endif;
				wp_reset_postdata();
			endif;
			
			$ajaxvars = array(
				'ajaxurl' => admin_url( 'admin-ajax.php' )
			);
			wp_localize_script( 'daze_popout', 'ajaxvars', $ajaxvars);
			wp_enqueue_script( 'daze_popout' );
		}
	endif;
	add_action( 'wp_enqueue_scripts', 'daze_popout_register' );
	
	
/* FILTERS AND HOOKS
   ========================================================================== */
	if ( !function_exists( 'daze_popout_post_classes' ) ) :
	function daze_popout_post_classes( $daze_popout_post_class ) {
		
		$daze_popout_post_class[] = 'clearfix';
		
		$daze_popout_post_class[] = daze_popout_get_meta( 'daze_popout_hide_title' );
		$daze_popout_post_class[] = daze_popout_get_meta( 'daze_popout_img_position' );
		$daze_popout_post_class[] = daze_popout_get_meta( 'daze_popout_img_shape' );
		
		if( !get_the_content() ) {
			$daze_popout_post_class[] = 'img-only';
		}
		
		if( ( daze_popout_get_meta( 'daze_popout_infinite' ) != 'infinite' ) && !get_the_content() ) {
			$daze_popout_post_class[] = 'img-fixed';
		}
		
		return $daze_popout_post_class;
	}
	endif;
	add_filter( 'post_class', 'daze_popout_post_classes' );
?>