<?php
/* ==========================================================================
	Daze Instagram grid widget
	Daze - Premium WordPress Theme, by NordWood
========================================================================== */

add_action( 'widgets_init', 'daze_insta_grid_init' );
 
function daze_insta_grid_init() {
    register_widget( 'daze_insta_grid' );
}
 
class Daze_Insta_Grid extends WP_Widget { 	
    public function __construct() {
        $widget_ops = array(
            'classname' => 'insta insta-grid social-instagram clearfix',
            'description' => esc_html__( 'Show Instagram feed', 'daze' )
        );
 
        parent::__construct( 'daze_insta_grid', esc_html__( 'Daze Instagram grid', 'daze' ), $widget_ops );
		
		add_action( 'wp_enqueue_scripts', array($this, 'daze_insta_grid_assets') );
    }

	public function daze_insta_grid_assets() {
		wp_enqueue_script( 'daze_instagram_grid' );
	}
	
// Widget frontend
    function widget( $arg, $instance ) {
        extract($arg);		
		
		echo $before_widget;
		
		if( absint( $instance['valid'] == 1 ) ) {
			
			$get_title = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'Follow me on Instagram', 'daze' );
			$title = '<span class="social-icon"></span>' . apply_filters( 'widget_title', $get_title );
			
			if ( $get_title ) {
				echo $before_title . $title . $after_title;	
			}	
			
			$i_user = isset( $instance['i_user'] ) ? $instance['i_user'] : 'nordwood';
			$num = isset( $instance['num'] ) ? absint( $instance['num'] ) : 9;
		
			$user = wp_remote_get( esc_url_raw( 'http://instagram.com/'.$i_user ) );
			$user_body = explode( 'window._sharedData = ', $user['body'] );
			$insta_json 	= explode( ';</script>', $user_body[1] );
			$user_array 	= json_decode( $insta_json[0], TRUE );
			
			$items = $user_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];			
			
			if( ( $count = $user_array['entry_data']['ProfilePage'][0]['user']['media']['count'] ) < $num ) {
				$num = $count;
			}
			
			for( $i = 0; $i < $num; $i++ ) {
				$item = $items[$i];
			?>
			<div class="item">
				<a style="background-image: url('<?php echo esc_url( $item['thumbnail_src'] ); ?>');" href="<?php echo esc_url('http://instagram.com/p/'.$item['code']); ?>" target="_blank" >
					<div class="overlay">
						<table class="stats"><tbody>
							<tr>
								<td>
									<span class="icon heart"></span>
									<span><?php echo absint( $item['likes']['count'] ); ?></span>
								</td>
								<td>									
									<span class="icon comments"></span>
									<span><?php echo absint( $item['comments']['count'] ); ?></span>
								</td>
							</tr>
						</tbody></table>
					</div>
				</a>
			</div>		
			<?php		
			}
		}
		
		echo $after_widget;
    }
	
// Widget backend
    function form( $instance ) {	
		$defaults = array(
			'title' => esc_html__( 'Follow me on Instagram', 'daze' ),
			'i_user' => 'nordwood',
			'num' => 9
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		$errs = new WP_Error;
		
		$i_user = $instance['i_user'];
		$num = absint( $instance['num'] );
		$user = wp_remote_get( esc_url_raw( 'http://instagram.com/'.$i_user ) );
		$valid = 0;		
		
		if( $user['response']['message'] === 'OK' ) {
			$user_body = explode( 'window._sharedData = ', $user['body'] );
			$insta_json 	= explode( ';</script>', $user_body[1] );
			$user_array 	= json_decode( $insta_json[0], TRUE );			
			$valid = 1;
			
		} else if( $user['response']['code'] === 404 ) {
			$errs->add( 'response', esc_html__( 'No such profile found.', 'daze' ) );
			echo '<p style="color: #f00;">' . esc_html( $errs->get_error_message() ) . '</p>';
		
		} else {
			$errs->add( 'response', esc_html__( 'No response from that profile.', 'daze' ) );
			
		}
		
		$instance['valid'] =  $valid;	
	?>	
		<p>			
			<input type="hidden" class="widefat valid"
				name="<?php echo esc_attr( $this->get_field_name('valid') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('valid') ); ?>"
				value="<?php echo esc_attr( $instance['valid'] ); ?>"
			>
		</p>
		
		<p>	
			<label for="<?php echo esc_attr( $this->get_field_name('title') ); ?>"><?php esc_html_e( 'Title:', 'daze' ); ?></label>			
			<input type="text" class="widefat"
				name="<?php echo esc_attr( $this->get_field_name('title') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('title') ); ?>"
				value="<?php echo esc_attr( $instance['title'] ); ?>"
			>
		</p>
		
		<p>	
			<label for="<?php echo esc_attr( $this->get_field_name('i_user') ); ?>"><?php esc_html_e( 'Instagram username:', 'daze' ); ?></label>			
			<input type="text" class="widefat"
				name="<?php echo esc_attr( $this->get_field_name('i_user') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('i_user') ); ?>"
				value="<?php echo esc_attr( $instance['i_user'] ); ?>"
			>
		</p>
		
		<p>
			<input type="number"
				name="<?php echo esc_attr( $this->get_field_name('num') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('num') ); ?>"
				value="<?php echo esc_attr( $instance['num'] ); ?>"
			>
			<label for="<?php echo esc_attr( $this->get_field_id('num') ); ?>"><?php esc_html_e( 'Number of items', 'daze' ); ?></label>
		</p>
	<?php
    }
	
//saving widget data 
    function update( $new_instance, $old_instance ) {  
        $instance = $old_instance;		
		
        $instance['valid'] = absint( $new_instance['valid'] );
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        $instance['i_user'] = sanitize_text_field( $new_instance['i_user'] );
        $instance['num'] = absint( $new_instance['num'] );

        return $instance;
    }
}
?>