<?php
/* ==========================================================================
	Daze popular/latest posts widget
	Daze - Premium WordPress Theme, by NordWood
========================================================================== */

add_action( 'widgets_init', 'daze_top_posts_init' );
 
function daze_top_posts_init() {
    register_widget( 'daze_top_posts' );
}
 
class Daze_Top_Posts extends WP_Widget { 	
    public function __construct() {
        $widget_ops = array(
            'classname' => 'top-posts',
            'description' => esc_html__( 'Shows the latest and most viewed posts', 'daze' )
        );
 
        parent::__construct( 'daze_top_posts', esc_html__( 'Daze popular/latest posts', 'daze' ), $widget_ops );
		
		add_action( 'wp_enqueue_scripts', array($this, 'daze_top_posts_assets') );
    }

	public function daze_top_posts_assets() {
		wp_enqueue_style( 'daze_top_posts' );
		wp_enqueue_script( 'daze_top_posts' );
	}
	
// Widget frontend
    function widget( $arg, $instance ) {
        extract($arg);
		
		echo $before_widget;
				
		$show_popular = isset( $instance['tp_show_popular'] ) ? $instance['tp_show_popular'] : 1;
		$show_latest = isset( $instance['tp_show_latest'] ) ? $instance['tp_show_latest'] : 1;
		$tp_hide_comments = isset( $instance['tp_hide_comments'] ) ? $instance['tp_hide_comments'] : 0;
		$tp_hide_date = isset( $instance['tp_hide_date'] ) ? $instance['tp_hide_date'] : 0;
		
		if ( $show_popular == 1 && $show_latest != 1 ) :
		?>
			<h3><?php esc_html_e( 'Popular Posts', 'daze' ); ?></h3>
		<?php
		endif;
		
		if ( $show_popular != 1 && $show_latest == 1 ) :
		?>
			<h3><?php esc_html_e( 'Latest Posts', 'daze' ); ?></h3>
		<?php
		endif;
				
	?>	
		<div class="nav-container"></div>
		
		<div class="top-posts-slider">
		<?php
		if( $show_popular == 1 ) :
		?>
			<div data-thumb="<?php esc_attr_e( 'Popular', 'daze' ); ?>">
		<?php
			$popular_args = array(
				'posts_per_page' => isset( $instance['tp_num_of_posts'] ) ? absint( $instance['tp_num_of_posts'] ) : 4,
				'meta_key' => 'daze_post_views_count',
				'orderby' => 'meta_value_num',
				'order' => 'DESC'
			);
			
			$popular_posts = new WP_Query( $popular_args );
			if( $popular_posts->have_posts() ) :
				while( $popular_posts->have_posts() ) :
					$popular_posts->the_post();
				?>
				<article class="clearfix">
					<div class="thumb">
					<?php
						$popular_thumb = daze_post_format_icon( get_the_ID() );
						
						if ( has_post_thumbnail( get_the_ID()) ) {
							$popular_thumb = get_the_post_thumbnail( get_the_ID(), 'daze_small' );
							
						} else if( get_post_format(get_the_ID()) == 'gallery' ) {
							$featured_gallery = get_post_meta( get_the_ID(), 'daze_featured_gallery', true );
							$get_gallery_imgs = explode(', ', $featured_gallery);
							
							if( $get_gallery_imgs == [""] ) {
								$get_gallery_imgs = [];
							}
							
							if( is_array( $get_gallery_imgs ) && !empty( $get_gallery_imgs ) ) {
								$popular_thumb = wp_get_attachment_image( $get_gallery_imgs[0], 'daze_small' );								
							}
						}
					?>
						<a href="<?php echo esc_url( get_permalink( get_the_ID() ) ); ?>"><?php echo $popular_thumb; ?></a>
					</div>
					
					<div class="content">
						<header>
						<?php
							$popular_title = get_the_title();
							if ( strlen( $popular_title ) > 59 ) {
								$popular_title = substr( $popular_title, 0, 56 );
								$popular_title .= '...';
							}
						?>
							<a href="<?php echo esc_url( get_permalink( get_the_ID() ) ); ?>"><h6><?php echo esc_html( $popular_title ); ?></h6></a>
						</header>
						
						<footer class="post-meta">
							<?php
								$tp_hide_views = isset( $instance['tp_hide_views'] ) ? $instance['tp_hide_views'] : 0;
								if( !$tp_hide_views ) {
									printf(
										'<span class="icon eye"></span><span>%d</span>',
										absint( daze_get_post_views( get_the_ID() ) )
									);
								}
								
								if( comments_open() && !$tp_hide_comments ) {
									if( !$tp_hide_views ) {
									?>
									<span class="separator"></span>
									<?php
									}
									
									$n = get_comments_number();
									
									printf(
										'<span class="icon comments-cloud"></span><span class="comments-count">%d</span>',
										absint($n)
									);
								}
							?>
						</footer>
					</div>
				</article>
				<?php
				endwhile;
			endif;
		?>
			</div>
		<?php
		endif;
		?>
			
		<?php
		if( $show_latest == 1 ) :
		?>
			<div data-thumb="<?php esc_attr_e( 'Latest', 'daze' ); ?>">
		<?php
			$latest_args = array(
				'numberposts' => isset( $instance['tp_num_of_posts'] ) ? absint( $instance['tp_num_of_posts'] ) : 4,
				'post_status' => 'publish',
				'orderby' => 'date',
				'order' => 'DESC'
			);
			
			$latest_posts = wp_get_recent_posts( $latest_args );
			if($latest_posts) :
				foreach( $latest_posts as $latest ) :
			?>
				<article class="clearfix">
					<div class="thumb">
					<?php
						$latest_thumb = daze_post_format_icon( $latest["ID"] );
						
						if ( has_post_thumbnail( $latest["ID"]) ) {
							$latest_thumb = get_the_post_thumbnail( $latest["ID"], 'daze_small' );
							
						} else if( get_post_format($latest["ID"]) == 'gallery' ) {
							$featured_gallery = get_post_meta( $latest["ID"], 'daze_featured_gallery', true );
							$get_gallery_imgs = explode(', ', $featured_gallery);
							
							if( $get_gallery_imgs == [""] ) {
								$get_gallery_imgs = [];
							}
							
							if( is_array( $get_gallery_imgs ) && !empty( $get_gallery_imgs ) ) {
								$latest_thumb = wp_get_attachment_image( $get_gallery_imgs[0], 'daze_small' );								
							}
						}
					?>
						<a href="<?php echo esc_url( get_permalink( $latest["ID"] ) ); ?>"><?php echo $latest_thumb; ?></a>
					</div>
					
					<div class="content">
						<header>
						<?php
							$latest_title = $latest["post_title"];
							if ( strlen( $latest_title) > 59 ) {
								$latest_title = substr( $latest_title, 0, 56 );
								$latest_title .= '...';
							}
						?>
							<a href="<?php echo esc_url( get_permalink( $latest["ID"] ) ); ?>"><h6><?php echo esc_html( $latest_title ); ?></h6></a>
						</header>
						
						<footer class="post-meta">
							<?php
								if( !$tp_hide_date ) {
									echo esc_html( get_the_date() );
								}								
								
								if( comments_open( $latest["ID"] ) && !$tp_hide_comments ) {
									$n = get_comments_number();
									
									if( !$tp_hide_date ) {
									?>
									<span class="separator"></span>
									<?php
									}
									
									printf(
										'<span class="icon comments-cloud"></span><span class="comments-count">%d</span>',
										absint($n)
									);
								}
							?>
						</footer>
					</div>
				</article>
			<?php 
				endforeach;
			endif;
			?>
			</div>
		<?php
		endif;
		?>
		</div>
	<?php		
		echo $after_widget;
    }
	
// Widget backend
    function form( $instance ) {	
		$defaults = array(
				'tp_num_of_posts' => 4,
				'tp_show_latest' => 1,
				'tp_show_popular' => 1,
				'tp_hide_views' => 0,
				'tp_hide_comments' => 0,
				'tp_hide_date' => 0
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
	?>	
		<p>
			<input type="number"
				name="<?php echo esc_attr( $this->get_field_name('tp_num_of_posts') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_num_of_posts') ); ?>"
				value="<?php echo esc_attr( $instance['tp_num_of_posts'] ); ?>"
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_num_of_posts') ); ?>"><?php esc_html_e( 'Number of posts', 'daze' ); ?></label>
		</p>
		
		<p>
			<input type="checkbox" value="1"
				name="<?php echo esc_attr( $this->get_field_name('tp_show_popular') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_show_popular') ); ?>"
				<?php checked( $instance['tp_show_popular'], 1 ); ?>
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_show_popular') ); ?>"><?php esc_html_e( 'Show popular posts', 'daze' ); ?></label>
		</p>
			
		<p>
			<input type="checkbox" value="1"
				name="<?php echo esc_attr( $this->get_field_name('tp_show_latest') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_show_latest') ); ?>"
				<?php checked( $instance['tp_show_latest'], 1 ); ?>
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_show_latest') ); ?>"><?php esc_html_e( 'Show latest posts', 'daze' ); ?></label>
		</p>
			
		<p>
			<input type="checkbox" value="1"
				name="<?php echo esc_attr( $this->get_field_name('tp_hide_views') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_hide_views') ); ?>"
				<?php checked( $instance['tp_hide_views'], 1 ); ?>
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_hide_views') ); ?>"><?php esc_html_e( 'Hide post views', 'daze' ); ?></label>
		</p>
			
		<p>
			<input type="checkbox" value="1"
				name="<?php echo esc_attr( $this->get_field_name('tp_hide_comments') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_hide_comments') ); ?>"
				<?php checked( $instance['tp_hide_comments'], 1 ); ?>
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_hide_comments') ); ?>"><?php esc_html_e( 'Hide comments count', 'daze' ); ?></label>
		</p>
			
		<p>
			<input type="checkbox" value="1"
				name="<?php echo esc_attr( $this->get_field_name('tp_hide_date') ); ?>"
				id="<?php echo esc_attr( $this->get_field_id('tp_hide_date') ); ?>"
				<?php checked( $instance['tp_hide_date'], 1 ); ?>
			>
			<label for="<?php echo esc_attr( $this->get_field_id('tp_hide_date') ); ?>"><?php esc_html_e( 'Hide date', 'daze' ); ?></label>
		</p>
			
	<?php
    }
	
//saving widget data 
    function update( $new_instance, $old_instance ) {  
        $instance = $old_instance;		
		
        $instance['tp_num_of_posts'] = absint( $new_instance['tp_num_of_posts'] );
		$instance['tp_show_latest'] = sanitize_text_field( $new_instance['tp_show_latest'] );
		$instance['tp_show_popular'] = sanitize_text_field( $new_instance['tp_show_popular'] );
		$instance['tp_hide_views'] = sanitize_text_field( $new_instance['tp_hide_views'] );
		$instance['tp_hide_comments'] = sanitize_text_field( $new_instance['tp_hide_comments'] );
		$instance['tp_hide_date'] = sanitize_text_field( $new_instance['tp_hide_date'] );

        return $instance;
    }
}
?>