<?php
/* ==========================================================================
	Template tags and helper functions
	Daze - Premium WordPress Theme, by NordWood
========================================================================== */

/* Retreive the classes for the #main as an array
   ========================================================================== */
	if( !function_exists( 'daze_get_main_class' ) ) :
		function daze_get_main_class( $class = '' ) {
			$classes = array();
			
			$classes[] = 'clearfix';
			
			if( is_home() || is_archive() || is_search() ) {
				$blog_layout_type = get_theme_mod( 'daze_blog_layout_type', 'masonry' );
				$blog_layout_width = get_theme_mod( 'daze_blog_layout_width', 'narrow' );
				$blog_sidebar = get_theme_mod( 'daze_include_sidebar', false );
				$pagination_type = get_theme_mod( 'daze_pagination_type', 'infinite_scroll' );
				
				if( is_tag() && get_theme_mod( 'daze_custom_tag_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_tag_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_tag_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_tag_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_tag_pagination_type', 'infinite_scroll' );
					
				} else if( is_date() && get_theme_mod( 'daze_custom_date_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_date_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_date_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_date_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_date_pagination_type', 'infinite_scroll' );
					
				} else if( is_author() && get_theme_mod( 'daze_custom_author_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_author_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_author_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_author_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_author_pagination_type', 'infinite_scroll' );
					
				} else if( is_category() && get_theme_mod( 'daze_custom_category_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_category_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_category_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_category_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_category_pagination_type', 'infinite_scroll' );
					
				} else if( is_search() && get_theme_mod( 'daze_custom_search_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_search_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_search_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_search_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_search_pagination_type', 'infinite_scroll' );
					
				} else if( is_archive() && get_theme_mod( 'daze_custom_archives_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_archives_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_archives_layout_width', 'narrow' );
					$blog_sidebar = get_theme_mod( 'daze_archives_include_sidebar', false );
					$pagination_type = get_theme_mod( 'daze_archives_pagination_type', 'infinite_scroll' );
				}
				
				if (
					!( 'standard-list' != $blog_layout_type && 'full-width' === $blog_layout_width )
					&& ( true === $blog_sidebar )
				) {
					$classes[] = 'include-sidebar';
				}
				
				
				
				
				$classes[] = ( 'infinite_scroll' === $pagination_type ) ? 'infinite-scroll' : 'standard-pagination' ;
			}
			
			if( is_single() && ( get_theme_mod('daze_include_sidebar_on_singles') || daze_get_meta( 'daze_include_sidebar' ) ) ) {
				$classes[] = 'include-sidebar';
			}
		 
			if ( ! empty( $class ) ) {
				if ( !is_array( $class ) )
					$class = preg_split( '#\s+#', $class );
				$classes = array_merge( $classes, $class );
				
			} else {
				$class = array();
			}
		 
			$classes = array_map( 'esc_attr', $classes );
			
			$classes = apply_filters( 'daze_main_class', $classes, $class );
		 
			return array_unique( $classes );
		}
	endif;

/* Display the classes for the #main
   ========================================================================== */
	if( !function_exists( 'daze_main_class' ) ) :
		function daze_main_class( $class = '' ) {
			// Separates classes with a single space, collates classes for #main
			echo 'class="' . join( ' ', daze_get_main_class( $class ) ) . '"';
		}
	endif;

/* Retreive the classes for the posts list holder as an array
   ========================================================================== */
	if( !function_exists( 'daze_get_layout_class' ) ) :
		function daze_get_layout_class( $class = '' ) {
			$classes = array();
			
			$classes[] = 'clearfix';
			
			if( is_home() || is_archive() || is_search() ) {
				$blog_layout_type = get_theme_mod( 'daze_blog_layout_type', 'masonry' );
				$blog_layout_width = get_theme_mod( 'daze_blog_layout_width', 'narrow' );
				$blog_cols_full = get_theme_mod( 'daze_blog_cols_full', 'four' );
				$blog_cols_narrow = get_theme_mod( 'daze_blog_cols_narrow', 'three' );
				$blog_sidebar = get_theme_mod( 'daze_include_sidebar', false );
				$hide_readmore = get_theme_mod( 'daze_hide_readmore', false );
				
				if( is_tag() && get_theme_mod( 'daze_custom_tag_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_tag_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_tag_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_tag_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_tag_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_tag_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_tag_hide_readmore', false );
					
				} else if( is_date() && get_theme_mod( 'daze_custom_date_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_date_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_date_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_date_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_date_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_date_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_archives_hide_readmore', false );
					
				} else if( is_author() && get_theme_mod( 'daze_custom_author_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_author_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_author_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_author_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_author_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_author_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_archives_hide_readmore', false );
					
				} else if( is_category() && get_theme_mod( 'daze_custom_category_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_category_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_category_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_category_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_category_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_category_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_archives_hide_readmore', false );
					
				} else if( is_search() && get_theme_mod( 'daze_custom_search_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_search_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_search_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_search_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_search_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_search_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_archives_hide_readmore', false );
					
				} else if( is_archive() && get_theme_mod( 'daze_custom_archives_layout', false ) ) {
					$blog_layout_type = get_theme_mod( 'daze_archives_layout_type', 'tiny' );
					$blog_layout_width = get_theme_mod( 'daze_archives_layout_width', 'narrow' );
					$blog_cols_full = get_theme_mod( 'daze_archives_cols_full', 'four' );
					$blog_cols_narrow = get_theme_mod( 'daze_archives_cols_narrow', 'three' );
					$blog_sidebar = get_theme_mod( 'daze_archives_include_sidebar', false );
					$hide_readmore = get_theme_mod( 'daze_archives_hide_readmore', false );
					
				}
				
				if( 'standard-list' != $blog_layout_type ) {
					$classes[] = 'masonry';
					$classes[] = 'masonry-list-wrapper';
					
					if( 'masonry-mini' === $blog_layout_type ) {
						$classes[] = 'masonry-mini';
					}
					
					if( 'tiny' === $blog_layout_type ) {
						$classes[] = 'tiny';
					}
					
					if( 'full-width' === $blog_layout_width ) {
						$classes[] = sanitize_html_class( $blog_cols_full ) . '-columns';
						
					} else {						
						$classes[] = ( $blog_sidebar )
									? 'two-columns'
									: sanitize_html_class( $blog_cols_narrow ) . '-columns';
					}
					
				} else {
					$classes[] = 'standard-list';
					
					if( true === $hide_readmore ) {
						$classes[] = 'hide-readmore';
					}
				}
			}
		 
			if ( ! empty( $class ) ) {
				if ( !is_array( $class ) )
					$class = preg_split( '#\s+#', $class );
				$classes = array_merge( $classes, $class );
			} else {
				$class = array();
			}
		 
			$classes = array_map( 'esc_attr', $classes );
			
			$classes = apply_filters( 'daze_layout_class', $classes, $class );
		 
			return array_unique( $classes );
		}
	endif;

/* Display the classes for the posts list holder
   ========================================================================== */
	if( !function_exists( 'daze_layout_class' ) ) :
		function daze_layout_class( $class = '' ) {
			echo 'class="' . join( ' ', daze_get_layout_class( $class ) ) . '"';
		}
	endif;

/* Retreive the classes for the posts slider image holder
   ========================================================================== */
	if( !function_exists( 'daze_get_nwps_bgr_class' ) ) :
		function daze_get_nwps_bgr_class( $class = '' ) {
			$classes = array();
			
			if ( has_post_thumbnail( get_the_ID() ) || daze_posts_get_meta( 'daze_posts_nwps_image_id', get_the_ID() ) ) {		
				$classes[] = 'has-bgr-img';
				
			} else {
				$classes[] = 'animated-bgr';
			}			
			
			$slider_type = get_theme_mod( 'daze_nwps_type', 'columns' );
			
			if( 'simple' === $slider_type ) {
				$classes[] = 'inner-wrapper';
				
			} else if( 'columns' === $slider_type ) {
				$classes[] = 'nwps-img';
				
			}
		 
			if ( ! empty( $class ) ) {
				if ( !is_array( $class ) )
					$class = preg_split( '#\s+#', $class );
				$classes = array_merge( $classes, $class );
				
			} else {
				$class = array();
			}
		 
			$classes = array_map( 'esc_attr', $classes );
			
			$classes = apply_filters( 'daze_nwps_bgr_class', $classes, $class );
		 
			return array_unique( $classes );
		}
	endif;

/* Display the classes for the posts slider image holder
   ========================================================================== */
	if( !function_exists( 'daze_nwps_bgr_class' ) ) :
		function daze_nwps_bgr_class( $class = '' ) {
			echo 'class="' . join( ' ', daze_get_nwps_bgr_class( $class ) ) . '"';
		}
	endif;

/* Image attachment display
   ========================================================================== */
// Get the post ID from its URL (mostly used for attachments)
	if ( !function_exists( 'daze_get_post_id_by_url' ) ) :
		function daze_get_post_id_by_url( $image_url ) {
			global $wpdb;
			$attachment = $wpdb->get_col(
				$wpdb->prepare(
					"SELECT ID FROM $wpdb->posts WHERE guid='%s';",
					esc_url_raw( $image_url )
				)
			);
			
			return $attachment[0];
		}
	endif;
	  
// Display attachment image by its url
	if ( !function_exists( 'daze_get_img_by_url' ) ) :
		function daze_get_img_by_url( $image_url, $size='daze_wrapper_width' ) {
			return wp_get_attachment_image( daze_get_post_id_by_url( $image_url ), $size );
		}
	endif;
	  
// Display gif images in original size, to keep the animation
	if ( !function_exists( 'daze_giffy_attachment' ) ) :
		function daze_giffy_attachment( $image_id, $img_size='daze_wrapper_width' ) {
			$size = ( get_post_mime_type( absint( $image_id ) ) == "image/gif" ) ? 'full' : $img_size;			
			return wp_get_attachment_image( $image_id, $size );
		}
	endif;
	if ( !function_exists( 'daze_giffy_featured_img' ) ) :
		function daze_giffy_featured_img( $post_id, $img_size='daze_wrapper_width' ) {
			$size = ( get_post_mime_type( get_post_thumbnail_id( absint( $post_id ) ) ) == "image/gif" ) ? 'full' : $img_size;			
			return get_the_post_thumbnail( $post_id, $size );
		}
	endif;
	
/*	Site logo display
   ========================================================================== */
	if ( !function_exists( 'daze_show_site_logo' ) ) :
		function daze_show_site_logo() {
			$site_logo_retina_url = get_theme_mod( 'daze_site_logo_retina' );
			$site_logo_url = get_theme_mod( 'daze_site_logo' );
			
		// Search for retina image first
			if( $site_logo_retina_url ) {
				$orig_img_W = wp_get_attachment_metadata(daze_get_post_id_by_url( esc_url_raw( $site_logo_retina_url ) ))['width'];
				$orig_img_H = wp_get_attachment_metadata(daze_get_post_id_by_url( esc_url_raw( $site_logo_retina_url ) ))['height'];
				printf( '<a href="%1$s" class="retina">%2$s</a>',
					esc_url( home_url( '/' ) ),
					daze_get_img_by_url( esc_url_raw( $site_logo_retina_url ), [$orig_img_W/2,$orig_img_H/2] )
				);
				
			} else if( $site_logo_url ) {
				printf( '<a href="%1$s">%2$s</a>',
					esc_url( home_url( '/' ) ),
					daze_get_img_by_url( esc_url_raw( $site_logo_url ), 'full' )
				);
			}
			
		// If no logo is provided, show the site title
			else {
				printf( '<a href="%1$s"><h1>%2$s</h1></a>',
					esc_url( home_url( '/' ) ),
					esc_html( get_bloginfo('name') )
				);		
			}	
		}
	endif;
	
/* Post views
   ========================================================================== */
	if ( !function_exists( 'daze_set_post_views' ) ) :   
		function daze_set_post_views( $postID ) {
			$count_key = 'daze_post_views_count';
			$count = get_post_meta( $postID, $count_key, true );
			
			if($count==''){
				$count = 0;
				delete_post_meta($postID, $count_key);
				add_post_meta($postID, $count_key, '0');
				
			} else{
				$count++;
				update_post_meta($postID, $count_key, $count);
			}
		}
	endif;
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

	if ( !function_exists( 'daze_get_post_views' ) ) :
		function daze_get_post_views($postID){
			$count_key = 'daze_post_views_count';
			$count = get_post_meta( $postID, $count_key, true );
			
			if($count==''){
				delete_post_meta( $postID, $count_key );
				add_post_meta($postID, $count_key, '0');
				return "0";
			}
			
			return $count;
		}
	endif;

/* Check if the post has a category (excluding 'Uncategorized')
   ========================================================================== */
	if ( !function_exists( 'daze_is_categorized' ) ) :   
		function daze_is_categorized($post_id) {
			$is_categorized = false;
			$terms = wp_get_object_terms( $post_id, 'category' );
			
			if( is_array($terms) ) :
				foreach( $terms as $index => $term ) :
					if ( 'uncategorized' === $term->slug ) {
						unset($terms[$index]);
					}
				endforeach;
				
				$is_categorized = ( count($terms)>0 );
			endif;
			
			return $is_categorized;
		}
	endif;	
	
/*	List of categories assigned to a post (excluding 'Uncategorized')
========================================================================== */
	if ( !function_exists( 'daze_post_categories' ) ) :
		function daze_post_categories($id) {
			$n = 0;
			$catlist = '';
			
			foreach( get_the_category($id) as $category ) {
				if ( $category->slug != 'uncategorized' ) {
					if( $n != 0 ) {
						$catlist .= '<span class="separator"></span>';
					}
					$n++;
					
					$catlist .= sprintf(
						'<a href="%1$s">%2$s</a>',
						esc_url( get_category_link( $category->term_id ) ),
						esc_html( $category->name )
					);
				}
			}
			
			echo $catlist;
		}
	endif;	
	
/*	Highlight searched term
   ========================================================================== */
	if( !function_exists('daze_highlight_searched_terms') ) :
	function daze_highlight_searched_terms( $text ) {
		$orig = $text;
		$sr = get_query_var('s');
		$keys = explode( " ", $sr );
		$keys = array_filter( $keys );
		$regEx = '\'(?!((<.*?)|(<a.*?)))(\b'. implode('|', $keys) . '\b)(?!(([^<>]*?)>)|([^>]*?</a>))\'iu';
		$text = preg_replace( $regEx, '<span class="search-highlight">\0</span>', $text );
		
		$result = is_search() ? $text : $orig;
		return $result;
	}
	endif;

/*	Pagination
   ========================================================================== */
	if( !function_exists('daze_posts_pagination') ) :
		function daze_posts_pagination( $numpages = '', $pagerange = '', $paged='' ) {
			if ( empty($pagerange) ) {
				$pagerange = 2;
			}
			
			global $paged;
			
			if (empty($paged)) {
				$paged = 1;
			}
			
			if ($numpages == '') {
				global $wp_query;
				
				$numpages = intval( $wp_query->max_num_pages );
				
				if(!$numpages) {
					$numpages = 1;
				}
			}
		  
			$pagination_args = array(
				'base'            => get_pagenum_link(1) . '%_%',
				'format'          => 'page/%#%',
				'base'            => add_query_arg( 'paged', '%#%' ),
				'format'          => '',
				'total'           => $numpages,
				'current'         => $paged,
				'show_all'        => false,
				'current'		  => max( 1, get_query_var('paged') ),
				'end_size'        => 1,
				'mid_size'        => $pagerange,
				'prev_next'       => false,
				'prev_text'       => '&laquo;',
				'next_text'       => '&raquo;',
				'type'            => 'list',
				'add_args'        => false,
				'add_fragment'    => ''
			);

			$paginate_links = paginate_links( $pagination_args );

			if ( $paginate_links ) :
			?>
			<div class="results-pagination clearfix">
				<?php
					if( get_previous_posts_link() ) {
						is_rtl()
						? previous_posts_link( sprintf(
							'<div class="prev">%s<span class="arrow right"></span></div>',
							esc_html__( 'Previous', 'daze')							
						))
						: previous_posts_link( sprintf(
							'<div class="prev"><span class="arrow left"></span>%s</div>',
							esc_html__( 'Previous', 'daze')
							
						));
						
					} else {
						is_rtl()
						? printf( '<div class="prev inactive">%s<span class="arrow right"></span></div>', esc_html__( 'Previous', 'daze') )
						: printf( '<div class="prev inactive"><span class="arrow left"></span>%s</div>', esc_html__( 'Previous', 'daze') );
					}
					
					if( get_next_posts_link() ) {
						is_rtl()
						? next_posts_link( sprintf(
							'<div class="next"><span class="arrow left"></span>%s</div>',
							esc_html__( 'Next', 'daze')							
						), $numpages)
						: next_posts_link( sprintf(
							'<div class="next">%s<span class="arrow right"></span></div>',
							esc_html__( 'Next', 'daze')
							
						), $numpages);
						
					} else {
						is_rtl()
						? printf( '<div class="next inactive"><span class="arrow left"></span>%s</div>', esc_html__( 'Next', 'daze') )
						: printf( '<div class="next inactive">%s<span class="arrow right"></span></div>', esc_html__( 'Next', 'daze') );
					}		
				?>				
				<div class="post-nums">					
				<?php echo $paginate_links; ?>
				</div>	
			</div>
			<?php
			endif;
		}
	endif;

/* Customize comment output
   ========================================================================== */
	if ( !function_exists( 'daze_comments_list' ) ) : 
		function daze_comments_list( $comment, $args, $depth ) {
			$GLOBALS['comment'] = $comment;
			$get_comment = get_comment( $comment );
			$comment_author_email = get_object_vars($get_comment)['comment_author_email'];
			$comment_class = "clearfix";
		?>
			<li <?php comment_class( $comment_class ); ?> id="comment-<?php comment_ID() ?>">
			
				<?php echo get_avatar($comment,$args['avatar_size']); ?>
				
				<div class="details">
					<h5 class="author-name"><?php 
						echo wp_kses(
							get_comment_author_link(),
							array( 'a' => array( 'href' => array(), 'rel' => array(), 'class' => array() ) )
						);
					?></h5>
					<p class="meta">
						<?php echo esc_html( date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), strtotime( $comment->comment_date ) ) ); ?>
					</p>
				</div>
				
				<div class="reply">
					<?php
					comment_reply_link(
						array_merge(
							$args,
							array(
								'reply_text' => esc_html__( 'Reply', 'daze' ),
								'depth' => $depth,
								'max_depth' => $args['max_depth']
							)
						),
						$comment->comment_ID
					);
					
					edit_comment_link( esc_html__( 'Edit', 'daze' ) ); ?>
				</div>
				<div class="comment-text">
				<?php
					if ( $comment->comment_approved == '0' ) :
						printf(
							'<em>%s</em>',
							esc_html_e( 'Comment awaiting approval', 'daze' )
						);
					endif;
					
					comment_text();
				?>
				</div>
			</li>
		<?php 
		}
	endif;
	
/*	Post format icon
   ========================================================================== */
	if ( !function_exists( 'daze_post_format_icon' ) ) :   
		function daze_post_format_icon( $post_id ) {
			$p_format = get_post_format( $post_id );
			
			switch ( $p_format ) {
				case 'image':
					$post_icon = '<span class="post-format-icon post-format-icon-image"></span>';
					break;
				case 'video':
					$post_icon = '<span class="post-format-icon post-format-icon-video"></span>';
					break;
				case 'quote':
					$post_icon = '<span class="post-format-icon post-format-icon-quote"></span>';
					break;
				case 'link':
					$post_icon = '<span class="post-format-icon post-format-icon-link"></span>';
					break;
				case 'gallery':
					$post_icon = '<span class="post-format-icon post-format-icon-gallery"></span>';
					break;
				case 'audio':
					$post_icon = '<span class="post-format-icon post-format-icon-audio"></span>';
					break;
				default:
					$post_icon = '<span class="post-format-icon post-format-icon-standard"></span>';
			}
			return $post_icon;
		}
	endif;
	

/*	Social links
   ========================================================================== */
	if ( !function_exists( 'daze_get_social_profiles' ) ) :
		function daze_get_social_profiles( $show_heading=false, $show_titles=false ) {
			
			$social_heading = esc_html( get_theme_mod( 'daze_social_heading' ) );
			
			$social_profiles_links = '';
		
		// Heading
			if( $show_heading && $social_heading && !is_rtl() ) {
				$social_profiles_links = $social_heading;
			}
		
		// Links		
			if($facebook_profile = get_theme_mod( 'daze_facebook_profile' )) {
				$social_profiles_links .= '<a class="social-facebook" href="' .  esc_url( $facebook_profile ) . '" target="_blank"><span class="social-icon"></span> ';
				if($show_titles==true) {
					$social_profiles_links .= '<span class="social-title">Facebook</span>';
				}
				$social_profiles_links .= '</a>';		
			}
			
			if($twitter_profile = get_theme_mod( 'daze_twitter_profile' )) {
				$social_profiles_links .= '<a class="social-twitter" href="' . esc_url( $twitter_profile ) . '" target="_blank"><span class="social-icon"></span> ';
				if($show_titles==true) {
					$social_profiles_links .= '<span class="social-title">Twitter</span>';
				}
				$social_profiles_links .= '</a>';
			}
			
			if($pinterest_profile = get_theme_mod( 'daze_pinterest_profile' )) {
				$social_profiles_links .= '<a class="social-pinterest" href="' . esc_url( $pinterest_profile ) . '" target="_blank"><span class="social-icon"></span> ';
				if($show_titles==true) {
					$social_profiles_links .= '<span class="social-title">Pinterest</span>';
				}
				$social_profiles_links .= '</a>';		
			}
			
			if($instagram_profile = get_theme_mod( 'daze_instagram_profile' )) {
				$social_profiles_links .= '<a class="social-instagram" href="' . esc_url( $instagram_profile ) . '" target="_blank"><span class="social-icon"></span> ';
				if($show_titles==true) {
					$social_profiles_links .= '<span class="social-title">Instagram</span>';
				}
				$social_profiles_links .= '</a>';		
			}
			
			if($gplus_profile = get_theme_mod( 'daze_gplus_profile' )) {
				$social_profiles_links .= '<a class="social-gplus" href="' . esc_url( $gplus_profile ) . '" target="_blank"><span class="social-icon"></span> ';
				if($show_titles==true) {
					$social_profiles_links .= '<span class="social-title">Google Plus</span>';
				}
				$social_profiles_links .= '</a>';
			}
			
		// Heading (rtl)
			if( $show_heading && $social_heading && is_rtl() ) {
				$social_profiles_links .= $social_heading;
			} 
			
			return $social_profiles_links;
		}
	endif;	
	
/* Social share
   ========================================================================== */
	if ( !function_exists( 'daze_share_buttons' ) ) :
		function daze_share_buttons() {	
		// Open container
			$share_buttons = '<div class="social share">';			
			$share_buttons .= '<span class="heading">' . esc_html__( 'Share this', 'daze' ) . '</span> ';			
		
		// Twitter
			$get_post_tags = get_the_tags( get_the_ID() );
			$post_tags = '';
			if ($get_post_tags) {
				foreach($get_post_tags as $tag) {
					$post_tags .= esc_html( $tag->name ) . ','; 
				}
			  
			  $post_tags = '&hashtags=' . rtrim($post_tags, ",");
			}
			$share_buttons .= '<a class="social-twitter" href="https://twitter.com/intent/tweet?url=' . rawurlencode( get_the_permalink() ) . '&text=' . get_the_title() . rtrim($post_tags, ","). '" target="_blank"><span class="social-icon"></span></a>';
			
		// Facebook
			$share_buttons .= '<a class="social-facebook" href="https://www.facebook.com/sharer/sharer.php?u=' . rawurlencode( get_the_permalink() ) . '" target="_blank"><span class="social-icon"></span></a>';
			
		// Pinterest
			$share_buttons .= '<a class="social-pinterest" data-pin-do="buttonPin" data-pin-count="above" data-pin-custom="true" href="https://www.pinterest.com/pin/create/button/?url=' . get_permalink() . '&media=' . wp_get_attachment_image_src(get_post_thumbnail_id( get_the_ID() ), 'daze_small')[0] . '&description=' . strip_tags( get_the_excerpt( get_the_ID() ) ) . '"><span class="social-icon"></span></a>';
			
		// Google Plus
			$share_buttons .= '<a class="social-gplus" href="https://plus.google.com/share?url=' . rawurlencode( get_the_permalink() ) . '" target="_blank"><span class="social-icon"></span></a>';			
			
		// Close container
			$share_buttons .= '</div>';	
			
			return $share_buttons;
		}
	endif;
	
/* Posts slider (simple)
   ========================================================================== */
	if ( !function_exists( 'daze_post_slider_simple' ) ) :
		function daze_post_slider_simple() {
			if( $get_number_of_posts = get_theme_mod( 'daze_nwps_num_of_posts' ) ) {
				$num_of_posts = $get_number_of_posts;
				
			} else {
				$num_of_posts = 5;
			}
			
			$featured_posts_args = array (
				'post_type' => 'post',
				'posts_per_page' => $num_of_posts,
				'meta_query' => array(
					array(
						'key'     => 'daze_posts_show_in_nwps',
						'value'   => 'show-in-nwps',
						'compare' => '='
					)
				),
				'ignore_sticky_posts' => 1
			);
			$nwps_query = new WP_Query( $featured_posts_args );

			if ( $nwps_query->have_posts() ) :				
			?>
				<div class="holder"></div>
				<div class="nwps simple">
			<?php
				$nwps_show_cat = ( get_theme_mod( 'daze_nwps_show_cat', true ) === true ) ? true : false;
				$nwps_show_date = ( get_theme_mod( 'daze_nwps_show_date', true ) === true ) ? true : false;
				$nwps_show_author = ( get_theme_mod( 'daze_nwps_show_author', true ) === true ) ? true : false;
				
				while ( $nwps_query->have_posts() ) :
					$nwps_query->the_post();
					
					if ( $get_nwps_image = daze_posts_get_meta( 'daze_posts_nwps_image_id', get_the_ID() ) ) {
						$nwps_image = wp_get_attachment_image_src( $get_nwps_image, 'full' )[0];
						
					} else if( has_post_thumbnail( get_the_ID() ) ) {
						$nwps_image = get_the_post_thumbnail_url( get_the_ID() );
						
					} else {
						$nwps_image = false;		
					}
					?>
			<div class="nwps-slide" >
				<div class="outer-wrapper">
					<div <?php daze_nwps_bgr_class(); ?> <?php if( $nwps_image ) { ?> style="background-image:url(<?php echo esc_url($nwps_image) ?>)" <?php } ?>>
						<div class="nwps-content post-header"  style="display: none;" >
					<?php
						if( $nwps_show_cat && daze_is_categorized( get_the_ID() ) ) {
						?>
							<h6 class="post-category"><?php daze_post_categories( get_the_ID() ); ?></h6>
						<?php
						}
						
						$post_title = get_the_title();
						?>
							<h3><a href="<?php echo esc_url( get_permalink( get_the_ID() ) ); ?>"><?php echo esc_html( $post_title ); ?></a></h3>
						<?php							
						if( $nwps_show_author || $nwps_show_date ) {
						?>
							<div class="post-meta">
						<?php
							if( $nwps_show_date ) {
								echo esc_html( get_the_date() );
							}
							
							if( $nwps_show_author && $nwps_show_date ) {
								echo " | ";
							}
							if( $nwps_show_author ) {
								is_rtl()
								? printf(
									'<a class="author-name" href="%2$s">%3$s</a> %1$s',
									esc_html__( 'Posted by', 'daze' ),
									esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ),
									esc_html( get_the_author_meta( "nickname" ) )
								)
								: printf(
									'%1$s <a class="author-name" href="%2$s">%3$s</a>',
									esc_html__( 'Posted by', 'daze' ),
									esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ),
									esc_html( get_the_author_meta( "nickname" ) )
								);
							}
						?>
							</div><!-- .post-meta -->
						<?php
						}
						?>
						</div><!-- .nwps-content -->						
					<?php
						$overlay_color = get_theme_mod( 'daze_nwps_overlay_color' ) ? get_theme_mod( 'daze_nwps_overlay_color', '#000' ) : '#000';
						$overlay_opacity = get_theme_mod( 'daze_nwps_overlay_opacity' ) ? get_theme_mod( 'daze_nwps_overlay_opacity', 15 ) : 15;
						$overlay_opacity = $overlay_opacity/100;
					?>
						<div class="overlay" style="background:<?php echo esc_attr( $overlay_color ); ?>; opacity:<?php echo floatval( $overlay_opacity ); ?>;"></div>
						
					<?php if( get_theme_mod( 'daze_nwps_grain_on', true ) ) : ?>
						<div class="noise"></div>
					<?php endif; ?>
					</div>
				</div>
			</div><!-- .nwps-slide -->
			<?php
				endwhile;
				wp_reset_postdata();
			?>
				</div><!-- .nwps.simple -->
			<?php
			endif;			
		}
	endif;
	
/* Featured Posts Slider (columns)
   ========================================================================== */
	if ( !function_exists( 'daze_post_slider_columns' ) ) :
		function daze_post_slider_columns() {
			if( $get_number_of_posts = get_theme_mod( 'daze_nwps_num_of_posts' ) ) {
				$num_of_posts = absint( $get_number_of_posts );
				
			} else {
				$num_of_posts = 6;
			}
			
			$featured_posts_args = array (
				'post_type' => 'post',
				'posts_per_page' => $num_of_posts,
				'meta_query' => array(
					array(
						'key'     => 'daze_posts_show_in_nwps',
						'value'   => 'show-in-nwps',
						'compare' => '='
					)
				),
				'ignore_sticky_posts' => 1
			);	
			$nwps_query = new WP_Query( $featured_posts_args );

			if ( $nwps_query->have_posts() ) :
			?>
			
			<div class="holder"></div>
			<div class="nwps columns">
			<?php
				$overlay_color = get_theme_mod( 'daze_nwps_overlay_color' ) ? get_theme_mod( 'daze_nwps_overlay_color', '#000' ) : '#000';
				$overlay_opacity = get_theme_mod( 'daze_nwps_overlay_opacity' ) ? get_theme_mod( 'daze_nwps_overlay_opacity', 15 ) : 15;
				$overlay_opacity = $overlay_opacity/100;
			?>
				<div class="overlay" style="background:<?php echo esc_attr( $overlay_color ); ?>; opacity:<?php echo floatval($overlay_opacity); ?>;"></div>
				
			<?php if( get_theme_mod( 'daze_nwps_grain_on', true ) ) { ?>
				<div class="noise"></div>
			<?php }
			
				$nwps_show_cat = ( get_theme_mod( 'daze_nwps_show_cat', true ) === true ) ? true : false;
				$nwps_show_date = ( get_theme_mod( 'daze_nwps_show_date', true ) === true ) ? true : false;
				$nwps_show_author = ( get_theme_mod( 'daze_nwps_show_author', true ) === true ) ? true : false;				
				
				$i=0;
		
				while ( $nwps_query->have_posts() ) :
					$nwps_query->the_post();
							
				// Get featured image
					if ( $get_nwps_image = daze_posts_get_meta( 'daze_posts_nwps_image_id', get_the_ID() ) ) {
						$nwps_image = wp_get_attachment_image_src( $get_nwps_image, 'full' )[0];
						
					} else if( has_post_thumbnail( get_the_ID() ) ) {
						$nwps_image = get_the_post_thumbnail_url( get_the_ID() );
						
					} else {
						$nwps_image = false;		
					}
					?>
					<div class="nwps-slide" data-curr-slide="<?php echo absint($i); ?>" >
						<div class="nwps-content post-header" style="display: none;" >
						<?php
						if( ( $nwps_show_cat && daze_is_categorized( get_the_ID() ) ) ) {
						?>
							<h6 class="post-category"><?php daze_post_categories( get_the_ID() ); ?></h6>
						<?php
						}
						
						$post_title = get_the_title();
						?>
							<h3><?php echo $post_title; ?></h3>
						<?php
						if( $nwps_show_author || $nwps_show_date ) {
						?>
							<div class="post-meta">
						<?php
							if( $nwps_show_date ) {
								echo esc_html( get_the_date() );
							}
							
							if( $nwps_show_author && $nwps_show_date ) {
								echo " | ";	
							}
							
							if( $nwps_show_author ) {
								is_rtl()
								? printf(
									'<a class="author-name" href="%2$s">%3$s</a> %1$s',
									esc_html__( 'Posted by', 'daze' ),
									esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ),
									esc_html( get_the_author_meta( "nickname" ) )
								)
								: printf(
									'%1$s <a class="author-name" href="%2$s">%3$s</a>',
									esc_html__( 'Posted by', 'daze' ),
									esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ),
									esc_html( get_the_author_meta( "nickname" ) )
								);
							}
						?>
							</div><!-- .post-meta -->
						<?php
						}
						?>
							<a class="read-more button-link" href="<?php echo esc_url( get_permalink() ); ?>">
								<?php esc_html_e( 'Read more', 'daze' ); ?>
								<svg><rect class="frame" stroke="#fff" width="1" height="1" ></rect><rect class="fill" fill="#fff" width="1" height="1" ></rect></svg>
							</a>
						</div><!-- .nwps-content -->
					</div><!-- .nwps-slide -->
					
					
					<div <?php daze_nwps_bgr_class(); ?>
						data-curr-slide="<?php echo absint($i); ?>"
						<?php if( $nwps_image ) { ?> style="background-image:url(<?php echo esc_url($nwps_image); ?>);" <?php } ?>
					></div>
					<?php
					$i++;
					
				endwhile;
				wp_reset_postdata();
			?>
				</div>
			<?php
			endif;
		}
	endif;
?>